@@ -172,7 +172,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
   test_that("ukfpopcheck2_randomdrift", {
     set.seed(1)
     nsubjects=60
-    Tpoints=50
+    Tpoints=20
     driftsd=.2
     driftmu= log(.5)
     dt=1
@@ -197,17 +197,16 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     dtm$pars$indvarying[dtm$pars$matrix %in% 'DRIFT'] <- TRUE
     
     dtf = ctStanFit(datalong = dat,ctstanmodel = dtm,optimize=TRUE,
-      cores=1,
-      verbose=0,optimcontrol=list(estonly=T),savescores = F,nopriors=T)
+      verbose=0,optimcontrol=list(estonly=F),savescores = F,nopriors=T)
     
        dtm2 <- ctModel(LAMBDA=matrix(c(1,0),1,2), type='stanct',
-      DIFFUSION=matrix(c('diff',0,0,0),2,2),DRIFT=matrix(c('state[2]|-2*log1p(exp(-2*param))',0,0,-.00001),2,2),
+      DIFFUSION=matrix(c('diff',0,0,0),2,2),DRIFT=matrix(c('-2*log1p(exp(-2*state[2]))',0,0,-.00001),2,2),
       CINT=matrix(c('cint',0),2,1),T0MEANS=matrix(c('t0m1','t0m2|param'),2,1),
       T0VAR=matrix(c('t0v11',0,0,paste0('t0var22 | ',gsub(".* sdscale","",gsub('rawpopsdbase','param',dtm$rawpopsdtransform),fixed=TRUE))),2,2),
       MANIFESTMEANS = matrix(0))
     
     dtm2$pars$indvarying <- FALSE
-    dtf2=ctStanFit(datalong = dat,ctstanmodel = dtm2,optimize = TRUE,optimcontrol=list(estonly=T),savescores = F,nopriors = T)
+    dtf2=ctStanFit(datalong = dat,ctstanmodel = dtm2,optimize = TRUE,nopriors = T)
     
     expect_equivalent(dtf2$stanfit$rawest,dtf$stanfit$rawest,tol=1e-2)
 
